@@ -1,6 +1,6 @@
 use utf8;
 package CPAN::Testers::Schema::ResultSet::Stats;
-our $VERSION = '0.017';
+our $VERSION = '0.018';
 # ABSTRACT: Query the raw test reports
 
 #pod =head1 SYNOPSIS
@@ -70,7 +70,7 @@ sub insert_test_report ( $self, $report ) {
         uploadid => $uploadid,
     };
 
-    return $schema->resultset('Stats')->create($stat);
+    return $schema->resultset('Stats')->update_or_create($stat, { key => 'guid' });
 }
 
 1;
@@ -85,7 +85,7 @@ CPAN::Testers::Schema::ResultSet::Stats - Query the raw test reports
 
 =head1 VERSION
 
-version 0.017
+version 0.018
 
 =head1 SYNOPSIS
 
@@ -132,7 +132,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by Oriol Soriano, Doug Bell.
+This software is copyright (c) 2017 by Oriol Soriano, Doug Bell.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
